@@ -16,7 +16,6 @@
  */
 
 #include "sysincludes.h"
-#include "msdos.h"
 #include "stream.h"
 #include "file.h"
 #include "mtoolsDirentry.h"
@@ -36,6 +35,35 @@ int isNotFound(direntry_t *entry)
 	return entry->entry == -2;
 }
 
+int isRootEntry(direntry_t *entry)
+{
+	return entry->entry == -3;
+}
+
+void setEntryForIteration(direntry_t *entry, unsigned int in) {
+	int out = (int) in;
+	assert(out >= 0);
+	entry->entry = out - 1;
+}
+
+void setEntryToPos(direntry_t *entry, unsigned int in) {
+	int out = (int) in;
+	assert(out >= 0);
+	entry->entry = out;
+}
+
+unsigned int getEntryAsPos(direntry_t *entry) {
+	int pos = entry->entry;
+	assert(pos >= 0);
+	return (unsigned int) pos;
+}
+
+unsigned int getNextEntryAsPos(direntry_t *entry) {
+	int pos = entry->entry+1;
+	assert(pos >= 0);
+	return (unsigned int) pos;
+}
+
 direntry_t *getParent(direntry_t *entry)
 {
 	return getDirentry(entry->Dir);
@@ -47,9 +75,9 @@ static size_t getPathLen(direntry_t *entry)
 	size_t length=0;
 
 	while(1) {
-		if(entry->entry == -3) /* rootDir */
+		if(isRootEntry(entry)) /* rootDir */
 			return length + 3;
-		
+
 		length += 1 + wcslen(entry->name);
 		entry = getDirentry(entry->Dir);
 	}
@@ -57,7 +85,7 @@ static size_t getPathLen(direntry_t *entry)
 
 static char *sprintPwd(direntry_t *entry, char *ptr, size_t *len_available)
 {
-	if(entry->entry == -3) {
+	if(isRootEntry(entry)) {
 		*ptr++ = getDrive(entry->Dir);
 		*ptr++ = ':';
 		*ptr++ = '/';
@@ -86,7 +114,7 @@ static char *sprintPwd(direntry_t *entry, char *ptr, size_t *len_available)
 
 static void _fprintPwd(FILE *f, direntry_t *entry, int recurs, int escape)
 {
-	if(entry->entry == -3) {
+	if(isRootEntry(entry)) {
 		putc(getDrive(entry->Dir), f);
 		putc(':', f);
 		if(!recurs)
@@ -120,7 +148,7 @@ void fprintPwd(FILE *f, direntry_t *entry, int escape)
 
 static void _fprintShortPwd(FILE *f, direntry_t *entry, int recurs)
 {
-	if(entry->entry == -3) {
+	if(isRootEntry(entry)) {
 		putc(getDrive(entry->Dir), f);
 		putc(':', f);
 		if(!recurs)
@@ -167,9 +195,9 @@ int isSubdirOf(Stream_t *inside, Stream_t *outside)
 	while(1) {
 		if(inside == outside) /* both are the same */
 			return 1;
-		if(getDirentry(inside)->entry == -3) /* root directory */
+		if(isRootEntry(getDirentry(inside))) /* root directory */
 			return 0;
 		/* look further up */
 		inside = getDirentry(inside)->Dir;
-	}			
+	}
 }
