@@ -21,18 +21,6 @@
 #include "stream.h"
 
 
-typedef struct FsPublic_t {
-	Class_t *Class;
-	int refs;
-	Stream_t *Next;
-	Stream_t *Buffer;
-
-	int serialized;
-	unsigned long serial_number;
-	uint8_t cluster_size;
-	uint16_t sector_size;
-} FsPublic_t;
-
 Stream_t *fs_init(char drive, int mode, int *isRop);
 int fat_free(Stream_t *Dir, unsigned int fat);
 int fatFreeWithDir(Stream_t *Dir, struct directory *dir);
@@ -40,4 +28,9 @@ int fat_error(Stream_t *Dir);
 uint32_t fat32RootCluster(Stream_t *Dir);
 char getDrive(Stream_t *Stream);
 
+typedef struct Fs_t Fs_t;
+bool getSerialized(Fs_t *File);
+unsigned long getSerialNumber(Fs_t *File);
+uint32_t getClusterBytes(Fs_t *File);
+
 #endif
