@@ -39,11 +39,11 @@ typedef struct Arg_t {
 void wipeEntry(direntry_t *entry)
 {
 	direntry_t longNameEntry;
-	int i;
+	unsigned int i;
 	initializeDirentry(&longNameEntry, entry->Dir);
 	for(i=entry->beginSlot; i< entry->endSlot; i++) {
 	    int error;
-	    longNameEntry.entry=i;
+	    setEntryToPos(&longNameEntry,i);
 	    dir_read(&longNameEntry, &error);
 	    if(error)
 		break;
@@ -61,7 +61,7 @@ static int del_entry(direntry_t *entry, MainParam_t *mp)
 	if(got_signal)
 		return ERROR_ONE;
 
-	if(entry->entry == -3) {
+	if(isRootEntry(entry)) {
 		fprintf(stderr, "Cannot remove root directory\n");
 		return ERROR_ONE;
 	}
